@@ -54,3 +54,11 @@ from truvari.stats import (
     format_stats,
     generate_stat_table
 )
+
+from truvari.annos.af_calc import allele_freq_annos
+
+from truvari.truv2df import (
+    vcf_to_df,
+    SZBINTYPE,
+    SVTYTYPE
+)
