@@ -29,7 +29,7 @@ def parse_args(args):
             raise argparse.ArgumentTypeError("%r not in range [0.0, 1.0]" % (x,))
         return x
 
-    parser = argparse.ArgumentParser(prog="truvari", description=__doc__,
+    parser = argparse.ArgumentParser(prog="bench", description=__doc__,
                                      formatter_class=argparse.RawDescriptionHelpFormatter)
     parser.add_argument("-b", "--base", type=str, required=True,
                         help="Baseline truth-set calls")
